@@ -50,12 +50,12 @@
     var opt = options || {};
     opt.path = opt.path || '/';
     var value = encodeURIComponent(val);
-    var str = name + '=' + value;
+    var str = "".concat(name, "=").concat(value);
 
     if (opt.maxAge > 0) {
       var maxAge = opt.maxAge - 0;
-      if (isNaN(maxAge)) throw new Error('maxAge should be a Number');
-      str += '; Max-Age=' + Math.floor(maxAge);
+      if (Number.isNaN(maxAge)) throw new Error('maxAge should be a Number');
+      str += "; Max-Age=".concat(Math.floor(maxAge));
     }
 
     if (opt.domain) {
@@ -63,7 +63,7 @@
         throw new TypeError('option domain is invalid');
       }
 
-      str += '; Domain=' + opt.domain;
+      str += "; Domain=".concat(opt.domain);
     }
 
     if (opt.path) {
@@ -71,7 +71,7 @@
         throw new TypeError('option path is invalid');
       }
 
-      str += '; Path=' + opt.path;
+      str += "; Path=".concat(opt.path);
     }
 
     if (opt.expires) {
@@ -79,7 +79,7 @@
         throw new TypeError('option expires is invalid');
       }
 
-      str += '; Expires=' + opt.expires.toUTCString();
+      str += "; Expires=".concat(opt.expires.toUTCString());
     }
 
     if (opt.httpOnly) str += '; HttpOnly';
@@ -129,7 +129,7 @@
       document.cookie = serializeCookie(name, encodeURIComponent(value), cookieOptions);
     },
     read: function read(name) {
-      var nameEQ = name + '=';
+      var nameEQ = "".concat(name, "=");
       var ca = document.cookie.split(';');
 
       for (var i = 0; i < ca.length; i++) {
@@ -339,21 +339,16 @@
   var subdomain = {
     name: 'subdomain',
     lookup: function lookup(options) {
-      var found;
+      // If given get the subdomain index else 1
+      var lookupFromSubdomainIndex = typeof options.lookupFromSubdomainIndex === 'number' ? options.lookupFromSubdomainIndex + 1 : 1; // get all matches if window.location. is existing
+      // first item of match is the match itself and the second is the first group macht which sould be the first subdomain match
+      // is the hostname no public domain get the or option of localhost
 
-      if (typeof window !== 'undefined') {
-        var language = window.location.href.match(/(?:http[s]*\:\/\/)*(.*?)\.(?=[^\/]*\..{2,5})/gi);
+      var language = typeof window !== 'undefined' && window.location && window.location.hostname && window.location.hostname.match(/^(\w{2,5})\.(([a-z0-9-]{1,63}\.[a-z]{2,6})|localhost)/i); // if there is no match (null) return undefined
 
-        if (language instanceof Array) {
-          if (typeof options.lookupFromSubdomainIndex === 'number') {
-            found = language[options.lookupFromSubdomainIndex].replace('http://', '').replace('https://', '').replace('.', '');
-          } else {
-            found = language[0].replace('http://', '').replace('https://', '').replace('.', '');
-          }
-        }
-      }
+      if (!language) return undefined; // return the given group match
 
-      return found;
+      return language[lookupFromSubdomainIndex];
     }
   };
 
@@ -366,8 +361,8 @@
       lookupSessionStorage: 'i18nextLng',
       // cache user language
       caches: ['localStorage'],
-      excludeCacheFor: ['cimode'] //cookieMinutes: 10,
-      //cookieDomain: 'myDomain'
+      excludeCacheFor: ['cimode'] // cookieMinutes: 10,
+      // cookieDomain: 'myDomain'
 
     };
   }
